using System;
using System.Collections.Generic;
using System.Data;
using System.Text;

using Vevo.Domain;
using Vevo.Domain.Products;
using Vevo.Shared.DataAccess;
using Vevo.Shared.Utilities;
using Vevo.Base.Data.Implementation;

namespace Vevo.Data.Implementation
{
    internal class ProductShippingCostAccess : BaseListedDataAccess<string, ProductShippingCost>
    {
        #region Private

        private ProductShippingCost CreateOneFromRow( DataRow row )
        {
            ProductShippingCost productShippingCost = new ProductShippingCost();
            productShippingCost.ProductID = row["ProductID"].ToString();
            productShippingCost.ShippingID = row["ShippingID"].ToString();
            productShippingCost.FixedShippingCost =
                ConvertUtilities.ToDecimal( row["FixedShippingCost"].ToString() );

            return productShippingCost;
        }

        private IList<ProductShippingCost> ConvertTableToList( DataTable table )
        {
            IList<ProductShippingCost> list = new List<ProductShippingCost>();
            foreach (DataRow row in table.Rows)
            {
                list.Add( CreateOneFromRow( row ) );
            }

            return list;
        }

        #endregion


        #region Protected

        protected override void Create( string productID, ProductShippingCost productShippingCost )
        {
            DataAccess.ExecuteNonQuery(
                "INSERT INTO ProductShippingCost (ProductID, ShippingID, FixedShippingCost)" +
                "VALUES (@ProductID, @ShippingID, @FixedShippingCost);",
                DataAccess.CreateParameterString( productID ),
                DataAccess.CreateParameterString( productShippingCost.ShippingID ),
                DataAccess.CreateParameterDecimal( productShippingCost.FixedShippingCost )
                );

            productShippingCost.ProductID = productID;
        }

        protected override void Update( string productID, ProductShippingCost productShippingCost )
        {
            int result = DataAccess.ExecuteNonQuery(
                "UPDATE ProductShippingCost SET " +
                "FixedShippingCost = @FixedShippingCost " +
                "WHERE ProductID = @ProductID " +
                "AND ShippingID = @ShippingID;",
                DataAccess.CreateParameterDecimal( productShippingCost.FixedShippingCost ),
                DataAccess.CreateParameterString( productShippingCost.ProductID ),
                DataAccess.CreateParameterString( productShippingCost.ShippingID )
                );

            if (result == 0)
            {
                DataAccess.ExecuteNonQuery(
                    "INSERT INTO ProductShippingCost (ProductID, ShippingID, FixedShippingCost)" +
                    "VALUES (@ProductID, @ShippingID, @FixedShippingCost);",
                    DataAccess.CreateParameterString( productShippingCost.ProductID ),
                    DataAccess.CreateParameterString( productShippingCost.ShippingID ),
                    DataAccess.CreateParameterDecimal( productShippingCost.FixedShippingCost )
                    );
            }
        }

        protected override void Delete( string productID, ProductShippingCost productShippingCost )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductShippingCost " +
                "WHERE ProductID = @ProductID " +
                "    AND ShippingID = @ShippingID; ",
                DataAccess.CreateParameterString( productShippingCost.ProductID ),
                DataAccess.CreateParameterString( productShippingCost.ShippingID ) );
        }

        #endregion


        #region Public Methods

        public void DeleteByProductID( string productID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductShippingCost " +
                "WHERE ProductID = @ProductID;",
                DataAccess.CreateParameterString( productID )
            );
        }

        public IList<ProductShippingCost> GetByProductID( string productID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID, ShippingID, FixedShippingCost " +
                "FROM ProductShippingCost " +
                "WHERE ProductID = @ProductID;",
                DataAccess.CreateParameterString( productID ) );

            return ConvertTableToList( table );
        }

        #endregion

    }

}
