using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Shared.DataAccess;
using Vevo.Domain.Shipping;
using Vevo.Domain;
using System.Data;
using Vevo.Shared.Utilities;

namespace Vevo.Data.Implementation
{
    internal class ShippingZoneAccess
    {
        private const string AllShippingZoneField = "ZoneGroupID, ShippingID ";

        private IList<ShippingZone> ConvertTableToList( DataTable table )
        {
            IList<ShippingZone> list = new List<ShippingZone>();

            foreach (DataRow row in table.Rows)
            {
                ShippingZone shippingZone = new ShippingZone();
                shippingZone.ShippingID = row["ShippingID"].ToString();
                shippingZone.ZoneGroupID = row["ZoneGroupID"].ToString();
                list.Add( shippingZone );
            }

            return list;
        }


        private void InsertShippingZones( string shippingID, IList<ShippingZone> shippingZones )
        {
            foreach (ShippingZone shippingZone in shippingZones)
            {
                int result = DataAccess.ExecuteNonQuery(
                    "INSERT INTO ShippingZone (ZoneGroupID, ShippingID) " +
                    "VALUES ( @ZoneGroupID, @ShippingID );",
                    DataAccess.CreateParameterString( shippingZone.ZoneGroupID ),
                    DataAccess.CreateParameterString( shippingID ) );
            }
        }


        public void SaveAll( string shippingID, IList<ShippingZone> shippingZones )
        {
            DeleteByShippingID( shippingID );
            InsertShippingZones( shippingID, shippingZones );
        }


        public int DeleteByShippingID( string shippingID )
        {
            return DataAccess.ExecuteNonQuery(
                "DELETE FROM ShippingZone " +
                "WHERE ShippingID = @ShippingID;",
                DataAccess.CreateParameterString( shippingID ) );
        }

        public IList<ShippingZone> GetByShippingID( string shippingID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT  " + AllShippingZoneField + "FROM ShippingZone " +
                "WHERE ShippingID = @ShippingID ORDER BY ZoneGroupID; ",
                DataAccess.CreateParameterString( shippingID ) );

            return ConvertTableToList( table );
        }
    }
}
