using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using Vevo.Base.Data.Caching;
using Vevo.Domain.Payments;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class PaymentLogRepository : IPaymentLogRepository
    {
        #region Private

        private const string RepositoryName = "PaymentLogRepository";

        private const string GetOneSignature = "GetOne";

        private const string TableName = "PaymentLog";

        private DataCache _dataCache = new DataCache( RepositoryName );
        private ICacheDependencyUtility _cacheDependency = new CacheDependencyUtility( TableName );
        private PaymentLogRepositoryNoCache _repository = new PaymentLogRepositoryNoCache();

        #endregion

        #region Constructors

        public PaymentLogRepository()
        {
        }

        public PaymentLogRepository( ICacheDependencyUtility cacheDependency )
        {
            _cacheDependency = cacheDependency;
        }

        #endregion

        #region Public Methods

        public PaymentLog Save( PaymentLog paymentLog )
        {
            // Need to write to database first before clearing cache.
            // Otherwise, cache may remember incorrect values before saving.
            PaymentLog newPaymentLog = _repository.Save( paymentLog );
            _dataCache.ClearRepositoryCache();
            return newPaymentLog;
        }

        public PaymentLog GetOne( string paymentLogID )
        {
            PaymentLog result = (PaymentLog) _dataCache.GetValue( GetOneSignature, _cacheDependency, paymentLogID );

            if (result == null)
            {
                result = _repository.GetOne( paymentLogID );
                _dataCache.SetValue( GetOneSignature, result, paymentLogID );
            }

            return result;
        }

        #endregion
    }
}
