using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Text;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Orders;
using Vevo.Shared.DataAccess;
using Vevo.Shared.Utilities;

namespace Vevo.Data
{
    public class RecurringProfileRepositoryNoCache : IRecurringProfileRepository
    {
        #region Private

        private const string AllRecurringProfileFields =
            "RecurringID, ReferenceID, RecurringStatus, RecurringInterval, RecurringIntervalUnit, " +
            "RecurringNumberOfCycles, RecurringNumberOfTrialCycles, BeginRecurringDate, EndRecurringDate, " +
            "BeginTrialDate, EndTrialDate, RecurringSequence, UpdateTime, TrialPrice, RegularPrice, " +
            "RecurringDescription, RegularTax, RegularShipping, RegularDiscount, " +
            "TrialTax, TrialShipping, TrialDiscount ";

        private RecurringProfile Create( RecurringProfile recurringProfile )
        {
            string newRecurringID = DataAccess.ExecuteScalar(
                    "INSERT INTO RecurringProfile ( ReferenceID, " +
                    "RecurringStatus, " +
                    "RecurringInterval, RecurringIntervalUnit, " +
                    "RecurringNumberOfCycles, RecurringNumberOfTrialCycles, " +
                    "BeginRecurringDate, EndRecurringDate, " +
                    "BeginTrialDate, EndTrialDate, " +
                    "UpdateTime, TrialPrice, RegularPrice, " +
                    "RecurringDescription, " +
                    "RegularShipping, RegularTax, RegularDiscount, " +
                    "TrialShipping, TrialTax, TrialDiscount, RecurringSequence " +
                    ") VALUES ( " +
                    "@ReferenceID, " +
                    "@RecurringStatus, " +
                    "@RecurringInterval, @RecurringIntervalUnit, " +
                    "@RecurringNumberOfCycles, @RecurringNumberOfTrialCycles, " +
                    "@BeginRecurringDate, @EndRecurringDate, " +
                    "@BeginTrialDate, @EndTrialDate, " +
                    "@UpdateTime, " +
                    "@TrialPrice, @RegularPrice, " +
                    "@RecurringDescription, " +
                    "@RegularShipping, @RegularTax, @RegularDiscount, " +
                    "@TrialShipping, @TrialTax, @TrialDiscount, @RecurringSequence " +
                    ");" +
                    "SELECT @@Identity;",
                    DataAccess.CreateParameterString( recurringProfile.ReferenceID ),
                    DataAccess.CreateParameterString( recurringProfile.RecurringStatus ),
                    DataAccess.CreateParameterInt32( recurringProfile.RecurringInterval ),
                    DataAccess.CreateParameterString( recurringProfile.RecurringIntervalUnit ),
                    DataAccess.CreateParameterInt32( recurringProfile.RecurringNumberOfCycles ),
                    DataAccess.CreateParameterInt32( recurringProfile.RecurringNumberOfTrialCycles ),
                    DataAccess.CreateParameterDateTime( recurringProfile.BeginRecurringDate ),
                    DataAccess.CreateParameterDateTime( recurringProfile.EndRecurringDate ),
                    DataAccess.CreateParameterDateTime( recurringProfile.BeginTrialDate ),
                    DataAccess.CreateParameterDateTime( recurringProfile.EndTrialDate ),
                    DataAccess.CreateParameterDateTime( recurringProfile.UpdateTime ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.TrialPrice ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.RegularPrice ),
                    DataAccess.CreateParameterString( recurringProfile.RecurringDescription ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.RegularShipping ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.RegularTax ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.RegularDiscount ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.TrialShipping ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.TrialTax ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.TrialDiscount ),
                    DataAccess.CreateParameterInt32( recurringProfile.RecurringSequence ) );

            recurringProfile.RecurringID = newRecurringID;
            return recurringProfile;
        }

        private RecurringProfile Update( RecurringProfile recurringProfile )
        {
            DataAccess.ExecuteNonQuery(
                "UPDATE RecurringProfile " +
                "SET " +
                "   ReferenceID = @ReferenceID, " +
                "   RecurringStatus = @RecurringStatus, " +
                "   RecurringInterval = @RecurringInterval, " +
                "   RecurringIntervalUnit = @RecurringIntervalUnit, " +
                "   RecurringNumberOfCycles = @RecurringNumberOfCycles, " +
                "   RecurringNumberOfTrialCycles = @RecurringNumberOfTrialCycles, " +
                "   BeginRecurringDate = @BeginRecurringDate, " +
                "   EndRecurringDate = @EndRecurringDate, " +
                "   BeginTrialDate = @BeginTrialDate, " +
                "   EndTrialDate = @EndTrialDate, " +
                "   UpdateTime = @UpdateTime, " +
                "   TrialPrice = @TrialPrice, " +
                "   RegularPrice = @RegularPrice, " +
                "   RecurringDescription = @RecurringDescription, " +
                "   RegularShipping = @RegularShipping, " +
                "   RegularTax = @RegularTax, " +
                "   RegularDiscount = @RegularDiscount, " +
                "   TrialShipping = @TrialShipping, " +
                "   TrialTax = @TrialTax, " +
                "   TrialDiscount = @TrialDiscount, " +
                "   RecurringSequence = @RecurringSequence " +
                " WHERE RecurringID = @RecurringID; ",
                DataAccess.CreateParameterString( recurringProfile.ReferenceID ),
                    DataAccess.CreateParameterString( recurringProfile.RecurringStatus ),
                    DataAccess.CreateParameterInt32( recurringProfile.RecurringInterval ),
                    DataAccess.CreateParameterString( recurringProfile.RecurringIntervalUnit ),
                    DataAccess.CreateParameterInt32( recurringProfile.RecurringNumberOfCycles ),
                    DataAccess.CreateParameterInt32( recurringProfile.RecurringNumberOfTrialCycles ),
                    DataAccess.CreateParameterDateTime( recurringProfile.BeginRecurringDate ),
                    DataAccess.CreateParameterDateTime( recurringProfile.EndRecurringDate ),
                    DataAccess.CreateParameterDateTime( recurringProfile.BeginTrialDate ),
                    DataAccess.CreateParameterDateTime( recurringProfile.EndTrialDate ),
                    DataAccess.CreateParameterDateTime( recurringProfile.UpdateTime ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.TrialPrice ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.RegularPrice ),
                    DataAccess.CreateParameterString( recurringProfile.RecurringDescription ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.RegularShipping ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.RegularTax ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.RegularDiscount ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.TrialShipping ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.TrialTax ),
                    DataAccess.CreateParameterDecimalMoney( recurringProfile.TrialDiscount ),
                    DataAccess.CreateParameterInt32( recurringProfile.RecurringSequence ),
                    DataAccess.CreateParameterString( recurringProfile.RecurringID ) );

            return recurringProfile;
        }

        private RecurringProfile CreateOneFromRow( DataRow row )
        {
            RecurringProfile recurringProfile = new RecurringProfile();
            recurringProfile.RecurringID = row["RecurringID"].ToString();
            recurringProfile.ReferenceID = row["ReferenceID"].ToString();
            recurringProfile.RecurringStatus = row["RecurringStatus"].ToString();
            recurringProfile.RecurringInterval = ConvertUtilities.ToInt32( row["RecurringInterval"] );
            recurringProfile.RecurringIntervalUnit = row["RecurringIntervalUnit"].ToString();
            recurringProfile.RecurringNumberOfCycles = ConvertUtilities.ToInt32( row["RecurringNumberOfCycles"] );
            recurringProfile.RecurringNumberOfTrialCycles = ConvertUtilities.ToInt32( row["RecurringNumberOfTrialCycles"] );
            recurringProfile.BeginRecurringDate = ConvertUtilities.ToDateTime( row["BeginRecurringDate"] );
            recurringProfile.EndRecurringDate = ConvertUtilities.ToDateTime( row["EndRecurringDate"] );
            recurringProfile.BeginTrialDate = ConvertUtilities.ToDateTime( row["BeginTrialDate"] );
            recurringProfile.EndTrialDate = ConvertUtilities.ToDateTime( row["EndTrialDate"] );
            recurringProfile.RecurringSequence = ConvertUtilities.ToInt32( row["RecurringSequence"] );
            recurringProfile.UpdateTime = ConvertUtilities.ToDateTime( row["UpdateTime"] );
            recurringProfile.TrialPrice = ConvertUtilities.ToDecimal( row["TrialPrice"] );
            recurringProfile.RegularPrice = ConvertUtilities.ToDecimal( row["RegularPrice"] );
            recurringProfile.RecurringDescription = row["RecurringDescription"].ToString();
            recurringProfile.RegularShipping = ConvertUtilities.ToDecimal( row["RegularShipping"] );
            recurringProfile.RegularTax = ConvertUtilities.ToDecimal( row["RegularTax"] );
            recurringProfile.RegularDiscount = ConvertUtilities.ToDecimal( row["RegularDiscount"] );
            recurringProfile.TrialShipping = ConvertUtilities.ToDecimal( row["TrialShipping"] );
            recurringProfile.TrialTax = ConvertUtilities.ToDecimal( row["TrialTax"] );
            recurringProfile.TrialDiscount = ConvertUtilities.ToDecimal( row["TrialDiscount"] );

            return recurringProfile;
        }

        private IList<RecurringProfile> ConvertTableToList( DataTable table )
        {
            return ConvertTableToList( table, 0, table.Rows.Count );
        }

        private IList<RecurringProfile> ConvertTableToList( DataTable table, int startIndex, int endIndex )
        {
            IList<RecurringProfile> list = new List<RecurringProfile>();

            for (int i = startIndex; i <= endIndex && i < table.Rows.Count; i++)
                list.Add( CreateOneFromRow( table.Rows[i] ) );

            return list;
        }

        private string CreateSortByText( string sortBy )
        {
            if (sortBy == null || sortBy.Trim() == "")
                return "";
            else
                return "ORDER BY " + sortBy;
        }

        #endregion

        #region Public

        public RecurringProfile Save( RecurringProfile recurringProfile )
        {
            RecurringProfile result;

            if (recurringProfile.RecurringID == "0")
                result = Create( recurringProfile );
            else
                result = Update( recurringProfile );

            return result;
        }

        public RecurringProfile GetOne( string recurringID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllRecurringProfileFields +
                "FROM RecurringProfile " +
                "WHERE RecurringID = @RecurringID; ",
                DataAccess.CreateParameterString( recurringID ) );

            if (table.Rows.Count > 0)
                return CreateOneFromRow( table.Rows[0] );
            else
                return RecurringProfile.Null;
        }

        public string GetOrderItemIDByReferenceID( string referenceID )
        {
            return DataAccess.ExecuteScalar(
                "SELECT OrderItem.OrderItemID " +
                "FROM " +
                "RecurringProfile LEFT JOIN " +
                "OrderItem ON RecurringProfile.RecurringID = OrderItem.RecurringID " +
                "WHERE ReferenceID = @ReferenceID;",
                DataAccess.CreateParameterString( referenceID ) );
        }

        public string GetRecurringIDFromReferenceID( string referenceID )
        {
            return DataAccess.ExecuteScalar(
                "SELECT RecurringID FROM RecurringProfile " +
                "WHERE ReferenceID = @ReferenceID ",
                DataAccess.CreateParameterString( referenceID ) );
        }

        public void Delete( string recurringID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE " +
                "FROM RecurringProfile " +
                "WHERE RecurringID = @RecurringID; ",
                DataAccess.CreateParameterString( recurringID ) );
        }
        #endregion
    }
}
