using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;

using Vevo.Base.Data.Caching;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Orders;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class WishListRepository : IWishListRepository
    {
        #region Private

        private const string RepositoryName = "WishListRepository";

        private const string GetOneSignature = "GetOne";
        private const string GetWishListItemByWishListIDSignature = "GetWishListItemByWishListID";
        private const string GetWishListIDFromCustomerIDSignature = "GetWishListIDFromCustomerID";
        private const string IsExistCustomerSignature = "IsExistCustomer";
        private const string TableName = "WishList";
        private DataCache _dataCache = new DataCache( RepositoryName );
        private ICacheDependencyUtility _cacheDependency = new CacheDependencyUtility( TableName );

        private WishListRepositoryNoCache _repository = new WishListRepositoryNoCache();

        #endregion

        #region Constructors

        public WishListRepository()
        {
        }

        public WishListRepository( ICacheDependencyUtility cacheDependency )
        {
            _cacheDependency = cacheDependency;
        }

        #endregion



        #region IWishListRepository Members

        public WishList Save( WishList wishList )
        {
            // Need to write to database first before clearing cache.
            // Otherwise, cache may remember incorrect values before saving.
            WishList newWishList = _repository.Save( wishList );
            _dataCache.ClearRepositoryCache();
            return newWishList;
        }

        public WishList GetOne( string wishListID )
        {
            WishList result = (WishList) _dataCache.GetValue( GetOneSignature, _cacheDependency, wishListID );

            if (result == null)
            {
                result = _repository.GetOne( wishListID );
                _dataCache.SetValue( GetOneSignature, result, wishListID );
            }

            return result;
        }

        public string GetWishListIDFromCustomerID( string customerID )
        {
            object result = _dataCache.GetValue( GetWishListIDFromCustomerIDSignature, _cacheDependency, customerID );

            if (result == null)
            {
                result = _repository.GetWishListIDFromCustomerID( customerID );
                _dataCache.SetValue( GetWishListIDFromCustomerIDSignature, result, customerID );
            }

            return result.ToString();
        }

        public bool IsExistCustomer( string customerID )
        {
            object result = _dataCache.GetValue(
                IsExistCustomerSignature,
                _cacheDependency,
                customerID
                );

            if (result == null)
            {
                result = _repository.IsExistCustomer( customerID );
                _dataCache.SetValue(
                    IsExistCustomerSignature,
                    result,
                    customerID );
            }

            return (bool) result;
        }

        public void DeleteAllByCustomerID( string customerID )
        {
            _repository.DeleteAllByCustomerID( customerID );
            _dataCache.ClearRepositoryCache();
        }

        public void DeleteAll()
        {
            _repository.DeleteAll();
            _dataCache.ClearRepositoryCache();
        }

        #endregion
    }
}
