﻿using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Domain.Orders;
using Vevo.Deluxe.Domain.EBay;
using Vevo.Domain;
using Vevo.Domain.Products;
using Vevo.WebUI;
using Vevo.Domain.Users;
using Vevo.Shared.Utilities;
using Vevo.Deluxe.Domain;
using Vevo.Deluxe.Domain.GiftRegistry;
using Vevo.Deluxe.Domain.Orders;

namespace Vevo.eBay
{
    public class EBayOrderUpdater
    {
        private bool IsEBayConfigReady()
        {
            if (DataAccessContext.Configurations.GetValue( "eBayConfigToken" ).ToString().Length <= 0)
                return false;
            else
                return true;
        }

        private bool CheckPastTimeLimit()
        {
            string lastTimeStr = DataAccessContext.Configurations.GetValue( "eBayOrderLastestUpdateTime" ).ToString();
            DateTime lastestTime;
            try
            {
                lastestTime = DateTime.ParseExact( lastTimeStr, "yyyy-MM-dd HH:mm tt", null );
            }
            catch
            {
                return true;
            }

            if ((DateTime.Now - lastestTime) > TimeSpan.FromMinutes( SystemConst.EBayUpdateLimitTimeRange ))
                return true;
            else
                return false;
        }

        private DateTime GetLastestUpdateTime()
        {
            string lastTimeStr = DataAccessContext.Configurations.GetValue( "eBayOrderLastestUpdateTime" ).ToString();
            DateTime lastestTime;
            try
            {
                lastestTime = DateTime.ParseExact( lastTimeStr, "yyyy-MM-dd HH:mm tt", null );
            }
            catch
            {
                DateTime saveTime = DateTime.Now.AddDays( -30 );
                SaveUpdateTime( saveTime );
                lastestTime = saveTime;
            }
            return lastestTime;
        }

        private void SaveUpdateTime( DateTime time )
        {
            DateTime saveTime = time;
            String timeString = saveTime.ToString( "yyyy-MM-dd HH:mm tt" );
            DataAccessContext.ConfigurationRepository.UpdateValue( DataAccessContext.Configurations["eBayOrderLastestUpdateTime"], timeString );
        }

        public void CreateUpdateOrdersFromEBayOrder()
        {
            if (!IsEBayConfigReady())
                return;

            if (!CheckPastTimeLimit())
                return;

            EBayAccess ebayAccess = new EBayAccess();

            DateTime start = GetLastestUpdateTime().AddDays( -1 );
            DateTime end = DateTime.Now;
            IList<EBayOrder> orders;
            try
            {
                orders = ebayAccess.GetOrders( start, end );
            }
            catch (Exception e)
            {
                SaveLogFile.SaveLog( e );
                return;
            }

            List<EBayOrder> new_orders = new List<EBayOrder>();
            foreach (EBayOrder order in orders)
            {
                IList<EBayListOrder> listOrders = DataAccessContextDeluxe.EBayListRepository.GetEBayListOrderByID( order.OrderID );
                if (listOrders.Count <= 0)
                {
                    foreach (EBayOrderTransaction trans in order.ItemTransactions)
                    {
                        IList<EBayList> lists = DataAccessContextDeluxe.EBayListRepository.GetEBayListByItemNumber( trans.ItemNumber );
                        if (lists.Count > 0)
                        {
                            new_orders.Add( order );
                            break;
                        }
                    }
                }
            }

            // Create Order from new order list
            string defaultCultureID = DataAccessContext.CultureRepository.GetIDByName( SystemConst.USCultureName );
            Culture defaultCulture = DataAccessContext.CultureRepository.GetOne( defaultCultureID );
            foreach (EBayOrder eBayOrder in new_orders)
            {
                CheckoutDetails checkoutDetails = new CheckoutDetails();
                if (eBayOrder.CheckoutMessage != null)
                    checkoutDetails.CustomerComments = eBayOrder.CheckoutMessage;
                else
                    checkoutDetails.CustomerComments = String.Empty;
                checkoutDetails.IsCreatedByAdmin = true;
                checkoutDetails.ShippingAddress = eBayOrder.ShippingAddress;
                checkoutDetails.StoreID = "0";

                string viewURLtext = String.Empty;
                foreach (EBayOrderTransaction trans in eBayOrder.ItemTransactions)
                {
                    IList<EBayList> lists = DataAccessContextDeluxe.EBayListRepository.GetEBayListByItemNumber( trans.ItemNumber );
                    viewURLtext += lists[0].ViewUrl + "<BR>";
                }


                viewURLtext = "<BR><BR>You can see full detail of order in following URL(s):<BR>" + viewURLtext;
                checkoutDetails.CustomerComments += viewURLtext;
                Currency currency = DataAccessContext.CurrencyRepository.GetOne( eBayOrder.Currency );
                OrderCreateService orderCreateService = new OrderCreateService(
                    Cart.Null,
                    checkoutDetails,
                    StoreContext.Culture,
                    currency,
                    String.Empty,
                    String.Empty );

                OrderAmount amount = orderCreateService.GetOrderAmount( Customer.Null )
                .Add( CartItemPromotion.CalculatePromotionShippingAndTax(
                StoreContext.CheckoutDetails,
                Cart.Null.SeparateCartItemGroups(),
                Customer.Null ) );

                Order order = orderCreateService.PlaceOrder(amount, Customer.Null, DataAccessContext.StoreRetriever, StoreContext.Culture );
                order.PaymentMethod = "eBay Payment";
                order.UserName = eBayOrder.BuyerID + " (eBay user)";
                order.PaymentComplete = eBayOrder.IsCheckoutCompleted;
                order = DataAccessContext.OrderRepository.Save( order );


                OrderItem orderItem = new OrderItem();
                orderItem.OrderID = order.OrderID;
                List<string> itemNumbers = new List<string>();
                foreach (EBayOrderTransaction trans in eBayOrder.ItemTransactions)
                {
                    itemNumbers.Add( trans.ItemName + "(" + trans.ItemNumber + ")" );
                }
                orderItem.Name = "eBay Products :" + String.Join( ", ", itemNumbers.ToArray() );
                orderItem.UnitPrice = ConvertUtilities.ToDecimal( ConvertUtilities.ToDouble( eBayOrder.Total ) / currency.ConversionRate );
                orderItem.Quantity = 1;
                order.OrderItems.Add( orderItem );
                DataAccessContext.OrderItemRepository.Save( orderItem );

                foreach (EBayOrderTransaction trans in eBayOrder.ItemTransactions)
                {
                    IList<EBayList> lists = DataAccessContextDeluxe.EBayListRepository.GetEBayListByItemNumber( trans.ItemNumber );
                    foreach (EBayList list in lists)
                    {
                        EBayListOrder listOrder = new EBayListOrder();
                        listOrder.OrderID = order.OrderID;
                        listOrder.EBayOrderID = eBayOrder.OrderID;
                        listOrder.ListID = list.ListID;
                        list.EBayListOrders.Add( listOrder );
                        DataAccessContextDeluxe.EBayListRepository.Save( list );
                    }
                }

                OrderEditService orderEditService = new OrderEditService();
                orderEditService.RefreshOrderAmount( order.OrderID );
            }

            SaveUpdateTime( DateTime.Now );
        }

    }
}
