using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Vevo;
using Vevo.DataAccessLib;
using Vevo.DataAccessLib.Cart;
using Vevo.Domain;
using Vevo.Domain.Users;
using Vevo.Shared.WebUI;
using Vevo.WebAppLib;
using Vevo.Domain.Stores;
using System.Collections.Generic;

public partial class Admin_Tools_AdminRecovery : Vevo.AdminBasePage
{
    private Store Store
    {
        get
        {
            Store store = DataAccessContext.StoreRepository.GetOne( "1" );
            if (store.IsNull)
            {
                IList<Store> storeList = DataAccessContext.StoreRepository.GetAll( "StoreID" );

                if (storeList.Count > 0)
                    return storeList[0];
            }

            return store;
        }
    }

    protected void Page_PreInit( object sender, EventArgs e )
    {
        Page.Theme = String.Empty;
    }

    protected void Page_Load( object sender, EventArgs e )
    {
        if (!IsPostBack)
        {
            PopulationControl();
        }
        uxMailPassword.Attributes.Add( "value", "$$$$$$" );
    }

    protected void Page_PreRender( object sender, EventArgs e )
    {
        if (Convert.ToBoolean( uxSmtpRequireDrop.SelectedValue.ToString() ))
        {
            uxSmtpmailTB.Visible = true;
        }
        else
        {
            uxSmtpmailTB.Visible = false;
            uxMailUserNameText.Text = string.Empty;
            uxMailPassword.Text = string.Empty;
            uxHiddenPassword.Value = "";
        }
    }

    protected void uxSubmitButton_Click( object sender, EventArgs e )
    {
        try
        {
            UserUtilities.SendResetPasswordConfirmationEmail( uxUserNameText.Text.ToString(), UrlPath.StorefrontUrl );
            uxSubmitMessage.DisplayMessage( "Please check your email for the password reset confirmation link." );
        }
        catch (VevoException ex)
        {
            uxSubmitMessage.DisplayError( "Error : " + ex.Message );
        }
    }

    protected void UpdateValue()
    {
        DataAccessContext.ConfigurationRepository.UpdateValue(
             DataAccessContext.Configurations["SmtpServer"],
            uxEmailServerText.Text, Store );

        DataAccessContext.ConfigurationRepository.UpdateValue(
             DataAccessContext.Configurations["SmtpPort"],
            uxEmailPortText.Text, Store );

        DataAccessContext.ConfigurationRepository.UpdateValue(
             DataAccessContext.Configurations["SmtpSslRequired"],
            uxRequireEmailSslDrop.SelectedValue.ToString(), Store );

        Admin admin = DataAccessContext.AdminRepository.GetOne( "1" );
        admin.Email = uxAdminEmailText.Text.Trim();
        admin = DataAccessContext.AdminRepository.Save( admin );
    }

    protected void PopulationControl()
    {
        Admin admin = DataAccessContext.AdminRepository.GetOne( "1" );

        uxEmailServerText.Text = DataAccessContext.Configurations.GetValue( "SmtpServer", Store );
        uxAdminEmailText.Text = admin.Email;
        uxEmailPortText.Text = DataAccessContext.Configurations.GetValue( "SmtpPort", Store );
        uxSmtpRequireDrop.SelectedValue = DataAccessContext.Configurations.GetValue( "SmtpAuthenRequired", Store );
        uxRequireEmailSslDrop.SelectedValue = DataAccessContext.Configurations.GetValue( "SmtpSslRequired", Store );
        uxMailUserNameText.Text = DataAccessContext.Configurations.GetValue( "SmtpUserName", Store );
        uxHiddenPassword.Value = DataAccessContext.Configurations.GetValue( "SmtpPassword", Store );
        uxRequireAdminSSLDrop.SelectedValue = DataAccessContext.Configurations.GetBoolValue("EnableAdminSSL").ToString();
    }

    protected void uxUpdateButton_Click( object sender, EventArgs e )
    {
        UpdateValue();
        if (Convert.ToBoolean( uxSmtpRequireDrop.SelectedValue.ToString() ))
        {
            if ((uxMailUserNameText.Text == "") || (uxMailPassword.Text == "$$$$$$"))
            {
                if (uxHiddenPassword.Value == "")
                {
                    uxUpdateMessage.DisplayError(
                        "Warnning:<br/>" + Resources.SetupMessages.ValidateEmailPassword );
                    return;
                }
                else
                {
                    if (uxMailPassword.Text != "$$$$$$")
                        DataAccessContext.ConfigurationRepository.UpdateValue(
                             DataAccessContext.Configurations["SmtpPassword"],
                            uxMailPassword.Text.Trim(), Store );
                    else
                        DataAccessContext.ConfigurationRepository.UpdateValue(
                             DataAccessContext.Configurations["SmtpPassword"],
                            uxHiddenPassword.Value, Store );
                }
            }
            else
            {
                DataAccessContext.ConfigurationRepository.UpdateValue(
                     DataAccessContext.Configurations["SmtpPassword"],
                    uxMailPassword.Text.Trim(), Store );
                uxHiddenPassword.Value = uxMailPassword.Text;
            }

            DataAccessContext.ConfigurationRepository.UpdateValue(
                 DataAccessContext.Configurations["SmtpUserName"],
                uxMailUserNameText.Text.Trim(), Store );
        }
        else
        {
            DataAccessContext.ConfigurationRepository.UpdateValue(
                 DataAccessContext.Configurations["SmtpUserName"],
               string.Empty, Store );

            DataAccessContext.ConfigurationRepository.UpdateValue(
                 DataAccessContext.Configurations["SmtpPassword"],
                string.Empty, Store );
        }

        DataAccessContext.ConfigurationRepository.UpdateValue(
             DataAccessContext.Configurations["SmtpAuthenRequired"],
            uxSmtpRequireDrop.SelectedValue.ToString(), Store );

        uxUpdateMessage.DisplayMessage( Resources.SetupMessages.UpdateSuccess );

        AdminUtilities.LoadSystemConfig();
        PopulationControl();
    }

    public override string StyleSheetTheme
    {
        get
        {
            return String.Empty;
        }
    }

    protected void uxUpdateAdminRecovery_Click(object sender, EventArgs e)
    {
        try
        {
            DataAccessContext.ConfigurationRepository.UpdateValue(
            DataAccessContext.Configurations["EnableAdminSSL"],
            uxRequireAdminSSLDrop.SelectedValue);

            uxUpdateAdminMessage.DisplayMessage("The configuration was updated successfully.");
        }
        catch (VevoException ex)
        {
            uxUpdateAdminMessage.DisplayError("Error : " + ex.Message);
        }
    }
}
